@@ -14,14 +14,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from debtcollector import removals
 from jinja2 import Template
 import jira
-from six.moves import urllib
-import ujson as json
-import yaml
-
-from debtcollector import removals
 from oslo_config import cfg
+import simplejson as json
+from six.moves import urllib
+import yaml
 
 from monasca_notification.plugins.abstract_notifier import AbstractNotifier
 
@@ -37,11 +36,6 @@ from monasca_notification.plugins.abstract_notifier import AbstractNotifier
 
    notification.address = https://<jira_url>/?project=<project_name>
 
-   Dependency for Jira
-       1) Jira plugin requires Jira library. Consumers need to install
-         JIRA via pip
-       2) (i.e) pip install jira
-
    Jira Configuration
        1) jira:
             user: username
@@ -229,6 +223,7 @@ class JiraNotifier(AbstractNotifier):
         if jira_comment_message:
             jira_obj.add_comment(issue, jira_comment_message)
 
+
 jira_notifier_group = cfg.OptGroup(name='%s_notifier' % JiraNotifier.type)
 jira_notifier_opts = [
     cfg.IntOpt(name='timeout', default=5, min=1),
