@@ -15,13 +15,13 @@
 # limitations under the License.
 
 import os
-import requests
-from six.moves import urllib
-import ujson as json
 
 from debtcollector import removals
 import jinja2
 from oslo_config import cfg
+import requests
+import simplejson as json
+from six.moves import urllib
 
 from monasca_notification.plugins import abstract_notifier
 
@@ -198,6 +198,7 @@ class SlackNotifier(abstract_notifier.AbstractNotifier):
                            .format(url, data_format))
         return False
 
+
 slack_notifier_group = cfg.OptGroup(name='%s_notifier' % SlackNotifier.type)
 slack_notifier_opts = [
     cfg.IntOpt(name='timeout', default=5, min=1),
