@@ -10,7 +10,8 @@
 # or implied. See the License for the specific language governing permissions and limitations under
 # the License.
 
-import mock
+from unittest import mock
+
 import six
 
 from monasca_notification import notification as m_notification
